@@ -25,6 +25,7 @@ def initBotWebhook(
 
     botId = get(message, 'ownerId')
     eventType = get(body, 'eventType')
+    msgType = get(body, 'type')
     groupId = get(body, 'groupId') or get(body, 'id')
     bot = getBot(botId)
     creatorId = get(body, 'creatorId')
@@ -37,10 +38,11 @@ def initBotWebhook(
     if eventType == 'GroupJoined':
       conf.botJoinPrivateChatAction(bot, groupId, user, dbAction)
 
-    elif eventType == 'PostAdded':
+    elif eventType == 'PostAdded' and msgType == 'TextMessage':
       # for bot self post, ignore
       if creatorId == botId:
         return defaultResponse
+      text = get(body, 'text') or ''
       handledByExtension = runExtensionFunction(
         extensions,
         'botGotPostAddAction',
@@ -48,17 +50,19 @@ def initBotWebhook(
         groupId,
         creatorId,
         user,
-        get(body, 'text'),
-        dbAction
+        text,
+        dbAction,
+        event
       )
       conf.botGotPostAddAction(
         bot,
         groupId,
         creatorId,
         user,
-        get(body, 'text'),
+        text,
         dbAction,
-        handledByExtension
+        handledByExtension,
+        event
       )
 
     elif eventType == 'Delete':
@@ -75,6 +79,30 @@ def initBotWebhook(
         dbAction
       )
 
+    else:
+      text = get(body, 'text') or ''
+      handledByExtension = runExtensionFunction(
+        extensions,
+        'defaultEventHandler',
+        bot,
+        groupId,
+        creatorId,
+        user,
+        text,
+        dbAction,
+        event
+      )
+      conf.defaultEventHandler(
+        bot,
+        groupId,
+        creatorId,
+        user,
+        text,
+        dbAction,
+        handledByExtension,
+        event
+      )
+
     return defaultResponse
 
   return botWebhook
\ No newline at end of file
