@@ -27,7 +27,8 @@ def botGotPostAddAction(
   user,
   text,
   dbAction,
-  handledByExtension
+  handledByExtension,
+  event
 ):
   """
   bot got group chat message: text
@@ -87,6 +88,21 @@ def botAuthAction(bot, dbAction):
   '''
   return
 
+def defaultEventHandler(
+  bot,
+  groupId,
+  creatorId,
+  user,
+  text,
+  dbAction,
+  handledByExtension,
+  event
+):
+  """
+  default event handler, for event not match any above
+  """
+  return
+
 def userAuthSuccessAction(bot, groupId, userId, dbAction):
   """
   user auth bot app to access user data success,
